pub struct ImageFeature { /* private fields */ }Expand description
Image feature flags.
Implementations
Sourceimpl ImageFeature
impl ImageFeature
Sourcepub const SAMPLED: ImageFeature
pub const SAMPLED: ImageFeature
Image view can be sampled.
Sourcepub const STORAGE: ImageFeature
pub const STORAGE: ImageFeature
Image view can be used as storage image.
Sourcepub const STORAGE_ATOMIC: ImageFeature
pub const STORAGE_ATOMIC: ImageFeature
Image view can be used as storage image (with atomics).
Sourcepub const COLOR_ATTACHMENT: ImageFeature
pub const COLOR_ATTACHMENT: ImageFeature
Image view can be used as color and input attachment.
Sourcepub const COLOR_ATTACHMENT_BLEND: ImageFeature
pub const COLOR_ATTACHMENT_BLEND: ImageFeature
Image view can be used as color (with blending) and input attachment.
Sourcepub const DEPTH_STENCIL_ATTACHMENT: ImageFeature
pub const DEPTH_STENCIL_ATTACHMENT: ImageFeature
Image view can be used as depth-stencil and input attachment.
Sourcepub const BLIT_SRC: ImageFeature
pub const BLIT_SRC: ImageFeature
Image can be used as source for blit commands.
Sourcepub const BLIT_DST: ImageFeature
pub const BLIT_DST: ImageFeature
Image can be used as destination for blit commands.
Sourcepub const SAMPLED_LINEAR: ImageFeature
pub const SAMPLED_LINEAR: ImageFeature
Image can be sampled with a (mipmap) linear sampler or as blit source
with linear sampling.
Requires SAMPLED or BLIT_SRC flag.
Sourcepub const fn empty() -> ImageFeature
pub const fn empty() -> ImageFeature
Returns an empty set of flags.
Sourcepub const fn all() -> ImageFeature
pub const fn all() -> ImageFeature
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u32) -> Option<ImageFeature>
pub const fn from_bits(bits: u32) -> Option<ImageFeature>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> ImageFeature
pub const fn from_bits_truncate(bits: u32) -> ImageFeature
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> ImageFeature
pub const unsafe fn from_bits_unchecked(bits: u32) -> ImageFeature
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: ImageFeature) -> bool
pub const fn intersects(&self, other: ImageFeature) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: ImageFeature) -> bool
pub const fn contains(&self, other: ImageFeature) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: ImageFeature)
pub fn insert(&mut self, other: ImageFeature)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: ImageFeature)
pub fn remove(&mut self, other: ImageFeature)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: ImageFeature)
pub fn toggle(&mut self, other: ImageFeature)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: ImageFeature, value: bool)
pub fn set(&mut self, other: ImageFeature, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: ImageFeature) -> ImageFeature
pub const fn intersection(self, other: ImageFeature) -> ImageFeature
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: ImageFeature) -> ImageFeature
pub const fn union(self, other: ImageFeature) -> ImageFeature
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: ImageFeature) -> ImageFeature
pub const fn difference(self, other: ImageFeature) -> ImageFeature
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: ImageFeature) -> ImageFeature
pub const fn symmetric_difference(self, other: ImageFeature) -> ImageFeature
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> ImageFeature
pub const fn complement(self) -> ImageFeature
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.