pub struct PresentMode { /* private fields */ }Expand description
Specifies the mode regulating how a swapchain presents frames.
Implementations
Sourceimpl PresentMode
impl PresentMode
Sourcepub const IMMEDIATE: PresentMode
pub const IMMEDIATE: PresentMode
Don’t ever wait for v-sync.
Sourcepub const MAILBOX: PresentMode
pub const MAILBOX: PresentMode
Wait for v-sync, overwrite the last rendered frame.
Sourcepub const FIFO: PresentMode
pub const FIFO: PresentMode
Present frames in the same order they are rendered.
Sourcepub const RELAXED: PresentMode
pub const RELAXED: PresentMode
Don’t wait for the next v-sync if we just missed it.
Sourcepub const fn empty() -> PresentMode
pub const fn empty() -> PresentMode
Returns an empty set of flags.
Sourcepub const fn all() -> PresentMode
pub const fn all() -> PresentMode
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u32) -> Option<PresentMode>
pub const fn from_bits(bits: u32) -> Option<PresentMode>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> PresentMode
pub const fn from_bits_truncate(bits: u32) -> PresentMode
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> PresentMode
pub const unsafe fn from_bits_unchecked(bits: u32) -> PresentMode
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: PresentMode) -> bool
pub const fn intersects(&self, other: PresentMode) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: PresentMode) -> bool
pub const fn contains(&self, other: PresentMode) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: PresentMode)
pub fn insert(&mut self, other: PresentMode)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: PresentMode)
pub fn remove(&mut self, other: PresentMode)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: PresentMode)
pub fn toggle(&mut self, other: PresentMode)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: PresentMode, value: bool)
pub fn set(&mut self, other: PresentMode, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: PresentMode) -> PresentMode
pub const fn intersection(self, other: PresentMode) -> PresentMode
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: PresentMode) -> PresentMode
pub const fn union(self, other: PresentMode) -> PresentMode
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: PresentMode) -> PresentMode
pub const fn difference(self, other: PresentMode) -> PresentMode
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: PresentMode) -> PresentMode
pub const fn symmetric_difference(self, other: PresentMode) -> PresentMode
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> PresentMode
pub const fn complement(self) -> PresentMode
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.