pub struct SurfaceCapabilities {
pub image_count: RangeInclusive<u32>,
pub current_extent: Option<Extent2D>,
pub extents: RangeInclusive<Extent2D>,
pub max_image_layers: u16,
pub usage: Usage,
pub present_modes: PresentMode,
pub composite_alpha_modes: CompositeAlphaMode,
}Expand description
Describes information about what a Surface’s properties are.
Fetch this with surface.compatibility(device).
Fields
image_count: RangeInclusive<u32>Number of presentable images supported by the adapter for a swapchain created from this surface.
image_count.startmust be at least 1.image_count.endmust be larger or equal toimage_count.start.
current_extent: Option<Extent2D>Current extent of the surface.
None if the surface has no explicit size, depending on the swapchain extent.
extents: RangeInclusive<Extent2D>Range of supported extents.
current_extent must be inside this range.
max_image_layers: u16Maximum number of layers supported for presentable images.
Must be at least 1.
usage: UsageSupported image usage flags.
present_modes: PresentModeA bitmask of supported presentation modes.
composite_alpha_modes: CompositeAlphaModeA bitmask of supported alpha composition modes.